#
# spec file for package ifuse
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           ifuse
Version:        1.1.4
Release:        1.13
Summary:        Filesystem access for Apple devices
License:        LGPL-2.0-or-later
Group:          System/Filesystems
URL:            https://www.libimobiledevice.org
Source:         https://github.com/libimobiledevice/ifuse/releases/download/%{version}/%{name}-%{version}.tar.bz2
BuildRequires:  fuse-devel
BuildRequires:  libimobiledevice-devel >= 1.3.0
BuildRequires:  libplist-2_0-devel >= 2.2.0
BuildRequires:  pkgconfig

%description
iFuse is a FUSE filesystem driver which uses `libimobiledevice` to connect to
devices without the need for a jailbreak.
It is using the native Apple "AFC" protocol, over the normal USB cable in order
to access the iPhone's, iPod Touch's or iPad's media files under Linux.

%prep
%setup -q

%build
%configure
%make_build

%install
%make_install

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%license COPYING
%doc AUTHORS README.md NEWS
%{_bindir}/ifuse
%{_mandir}/man1/ifuse.1%{?ext_man}

%changelog
* Mon Feb  1 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 1.1.4 (boo#1181620)
  * Use automake silent rules if available
  * Add helpful message when mounting an app document folder fails
  * Add new --list-apps option to print list of apps with file sharing enabled
  * Remove length check on UDID argument to support newer devices
  * Add --network option to allow connecting to network devices
  * Add title row and use double quotes for --list-apps output
  * Drop support for older versions of libimobiledevice
  * Bump libimobiledevice dependency to 1.3.0
  * Bump libplist dependency to 2.2.0
  * Improve README.md with project description, installation,
    contributing and usage sections
- Spec cleanup
* Tue Jun 17 2014 i@marguerite.su
- update version 1.1.3
  * Updated to compile with latest libimobiledevice
  * New command line options --documents and --container (obsoletes --appid)
  * Handle error condition caused by pending iOS7+ trust dialog
  * Minor fixes and changes
- drop patch: ifuse-libimobiledevice-1.1.5.patch
  * upstreamed
* Tue Jul 30 2013 opensuse@sukimashita.com
- Add support for libimobiledevice 1.1.5 backported from upstream
  git HEAD fixing build for openSUSE:Factory
- Add ifuse-libimobiledevice-1.1.5.patch
* Sat May 26 2012 jengelh@inai.de
- Remove redundant tags/sections from specfile
* Sun Apr  8 2012 opensuse@sukimashita.com
- Update to 1.1.2:
  * Add direct linking with libplist to fix build issues
  * Add basic manpage
  * Use UDID instead of UUID as it is the correct term for it
  * Remove obsolete glib and gthread dependencies
- Remove ifuse-fixasneeded.patch
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Wed Jan 12 2011 opensuse@sukimashita.com
- Update to 1.1.1:
  * Add "house_arrest" support when compiled with
    libimobiledevice >= 1.1.0
  * Add "--appid" option for document/filesharing using
    "house_arrest" service
  * FreeBSD doesn't have ENODATA, so fake it as EIO
  * Make COPYING contain correct license
  * Add NEWS file and update README
  * Minor bugfixes
* Mon May  3 2010 meissner@suse.de
- fixed asneeded problem correctly
* Tue Mar 23 2010 opensuse@sukimashita.com
- Update to 1.0.0:
  * Return correct exit status on failure
  * Fix renamed define due to changes in libimobiledevice
* Tue Feb  2 2010 opensuse@sukimashita.com
- Update to 0.9.7:
  * Port to libimobiledevice project name change
* Sat Jan 23 2010 opensuse@sukimashita.com
- Update to 0.9.6:
  * Port to libiphone 0.9.6 API
  * Improve error message on failed root filesystem access
  * Notify user if startup fails due to the device having a
    password set
  * Fix handling of uuid command line argument
  * Remove hardcoded allow_other fuse argument
* Tue Nov 24 2009 opensuse@sukimashita.com
- Update to 0.9.5:
  * support file modification times on OS 3.1 and later
* Thu Oct 29 2009 opensuse@sukimashita.com
- Update to 0.9.4:
  * Renamed and moved binary to /usr/bin/ifuse
  * Rewrite option handling and connect to a specific device
  * Remove HAL automounting hack
  * Update to latest libiphone API
  * Userspace mounting is now preferred
* Thu Aug  6 2009 opensuse@sukimashita.com
- Update to 0.9.3:
  * Moved some libiphone logic into iFuse and adopted to new API
  * Add hard/symlink/locking support
  * Add iPhone 3GS support
  * Improved error code handling
* Wed May 13 2009 opensuse@sukimashita.com
- Update to 0.9.1:
  * Autotools fixes
* Sun May 10 2009 opensuse@sukimashita.com
- Update to 0.9.0:
  * Handle file modes correctly
  * Improve error handling
  * Remove references of obsolete libiphone-initconf
  * Bugfixes
* Sat Apr 11 2009 opensuse@sukimashita.com
- Update to latest git HEAD
* Sat Apr  4 2009 opensuse@sukimashita.com
- Make BuildRequires use libiphone-devel without so version
* Sat Jan 31 2009 opensuse@sukimashita.com
- Initial package created
